@@ -1,3 +1,6 @@
+import bz2
+import gzip
+import zipfile
 from functools import lru_cache
 from io import TextIOWrapper
 from pathlib import Path
@@ -25,6 +28,7 @@ class Genbank:
         ----------
         gbk_source : Union[str, Path, TextIOWrapper]
             Genbank file or source
+            (`.gz`, `.bz2`, `.zip` format file is automatically uncompressed)
         name : Optional[str]
             name (If None, `file name` or `record name` is set)
         reverse : bool, optional
@@ -36,7 +40,7 @@ class Genbank:
         """
         self._gbk_source = gbk_source
         self._name = name
-        self._records: List[SeqRecord] = list(SeqIO.parse(gbk_source, "genbank"))
+        self._records = self._parse_gbk_source(gbk_source)
         self.reverse = reverse
         self.min_range = 1 if min_range is None else min_range
         self.max_range = self.full_genome_length if max_range is None else max_range
@@ -47,13 +51,47 @@ class Genbank:
             err_msg += f"'1 <= min_range <= max_range <= {self.full_genome_length}'"
             raise ValueError(err_msg)
 
+    def _parse_gbk_source(
+        self, gbk_source: Union[str, Path, TextIOWrapper]
+    ) -> List[SeqRecord]:
+        """Parse genbank source
+
+        Parameters
+        ----------
+        gbk_source : Union[str, Path, TextIOWrapper]
+            Genbank file or source
+
+        Returns
+        -------
+        List[SeqRecord]
+            Genbank SeqRecords
+        """
+        # Parse compressed file
+        if isinstance(gbk_source, (str, Path)):
+            if Path(gbk_source).suffix == ".gz":
+                with gzip.open(gbk_source, mode="rt") as f:
+                    return list(SeqIO.parse(f, "genbank"))
+            elif Path(gbk_source).suffix == ".bz2":
+                with bz2.open(gbk_source, mode="rt") as f:
+                    return list(SeqIO.parse(f, "genbank"))
+            elif Path(gbk_source).suffix == ".zip":
+                with zipfile.ZipFile(gbk_source) as zip:
+                    with zip.open(zip.namelist()[0]) as f:
+                        return list(SeqIO.parse(TextIOWrapper(f), "genbank"))
+        # Parse no compressed file or TextIOWrapper
+        return list(SeqIO.parse(gbk_source, "genbank"))
+
     @property
     def name(self) -> str:
         """Name"""
         if self._name is not None:
             return self._name
         if isinstance(self._gbk_source, (str, Path)):
-            return Path(self._gbk_source).with_suffix("").name
+            gbk_file = Path(self._gbk_source)
+            if gbk_file.suffix in (".gz", ".bz2", ".zip"):
+                return gbk_file.with_suffix("").with_suffix("").name
+            else:
+                return gbk_file.with_suffix("").name
         elif isinstance(self._gbk_source, TextIOWrapper):
             return self._records[0].name
         else:
@@ -103,7 +141,7 @@ class Genbank:
         Parameters
         ----------
         window_size : int, optional
-            Window size (Default: `genome_size / 400`)
+            Window size (Default: `genome_size / 500`)
         step_size : int, optional
             Step size (Default: `genome_size / 1000`)
 
@@ -115,7 +153,7 @@ class Genbank:
         pos_list, gc_skew_list = [], []
         seq = self.genome_seq
         if window_size is None:
-            window_size = int(len(seq) / 400)
+            window_size = int(len(seq) / 500)
         if step_size is None:
             step_size = int(len(seq) / 1000)
         for i in range(0, len(seq), step_size):
@@ -147,7 +185,7 @@ class Genbank:
         Parameters
         ----------
         window_size : int, optional
-            Window size (Default: `genome_size / 400`)
+            Window size (Default: `genome_size / 500`)
         step_size : int, optional
             Step size (Default: `genome_size / 1000`)
 
@@ -159,7 +197,7 @@ class Genbank:
         pos_list, gc_content_list = [], []
         seq = self.genome_seq
         if window_size is None:
-            window_size = int(len(seq) / 400)
+            window_size = int(len(seq) / 500)
         if step_size is None:
             step_size = int(len(seq) / 1000)
         for i in range(0, len(seq), step_size):
@@ -226,9 +264,16 @@ class Genbank:
                         not min_range <= start <= max_range
                         and not min_range <= end <= max_range
                     ):
+                        # Ignore completely out of range features
                         continue
+                    # If partially within range, fix position to within range
+                    if start <= min_range <= end <= max_range:
+                        start = min_range
+                    if min_range <= start <= max_range <= end:
+                        end = max_range
                 else:
                     if not min_range <= start <= end <= max_range:
+                        # Ignore out of range features
                         continue
                 # Extract only target strand feature
                 if target_strand is not None and f.strand != target_strand:
@@ -252,6 +297,7 @@ class Genbank:
     def write_cds_fasta(
         self,
         fasta_outfile: Union[str, Path],
+        allow_partial: bool = False,
     ):
         """Write CDS protein features fasta file
 
@@ -260,7 +306,7 @@ class Genbank:
         fasta_outfile : Union[str, Path]
             CDS fasta file
         """
-        features = self.extract_features("CDS", None, fix_position=False)
+        features = self.extract_features("CDS", None, False, allow_partial)
         cds_seq_records: List[SeqRecord] = []
         for idx, feature in enumerate(features, 1):
             qualifiers = feature.qualifiers
