@@ -2,10 +2,10 @@ from __future__ import annotations
 
 import warnings
 from pathlib import Path
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Tuple, Union
 
 import matplotlib.pyplot as plt
-from matplotlib import colors, gridspec, patches
+from matplotlib import colors, gridspec
 from matplotlib.colorbar import ColorbarBase
 from matplotlib.figure import Axes, Figure
 from matplotlib.ticker import MaxNLocator
@@ -39,8 +39,9 @@ class GenomeViz:
             Figure width
         fig_track_height : float, optional
             Figure track height
+            (Figure height = `track number` * `fig track height`)
         align_type : str, optional
-            Track align type
+            Track align type (`left`|`center`|`height`)
         feature_track_ratio : float, optional
             Feature track ratio
         link_track_ratio : float, optional
@@ -153,6 +154,7 @@ class GenomeViz:
         labelsize: int = 20,
         labelmargin: float = 0.01,
         linewidth: int = 1,
+        linecolor: str = "grey",
     ) -> FeatureTrack:
         """Add feature track
 
@@ -168,6 +170,8 @@ class GenomeViz:
             Track label margin
         linewidth : int, optional
             Track line width
+        linecolor : str, optional
+            Track line color
 
         Returns
         -------
@@ -193,6 +197,7 @@ class GenomeViz:
             labelsize,
             labelmargin,
             linewidth,
+            linecolor,
             self.track_spines,
             self.feature_track_ratio,
         )
@@ -240,7 +245,8 @@ class GenomeViz:
         vmin: float = 0,
         vmax: float = 100,
         curve: bool = False,
-        size_ratio: float = 0.9,
+        size_ratio: float = 1.0,
+        patch_kws: Optional[Dict[str, Any]] = None,
     ) -> None:
         """Add link data to link track
 
@@ -266,6 +272,10 @@ class GenomeViz:
             If True, bezier curve link is plotted
         size_ratio : float, optional
             Link size ratio to track
+        patch_kws : Optional[Dict[str, Any]], optional
+            Optional keyword arguments to pass to link Patch object.
+            See https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html
+            for detailed parameters.
         """
         link_track = self._get_link_track(track_link1[0], track_link2[0])
         tracks = [t.name for t in self.get_tracks()]
@@ -291,6 +301,7 @@ class GenomeViz:
                 vmax,
                 curve,
                 size_ratio,
+                patch_kws,
             )
         )
 
@@ -312,7 +323,7 @@ class GenomeViz:
             track_name2track[track.name] = track
         if track_name not in track_name2track.keys():
             err_msg = f"track.name='{track_name}' is not found."
-            raise KeyError(err_msg)
+            raise ValueError(err_msg)
         return track_name2track[track_name]
 
     def get_tracks(self, subtrack: bool = False) -> List[Track]:
@@ -347,6 +358,15 @@ class GenomeViz:
             raise ValueError(err_msg)
         return feature_tracks[0]
 
+    @property
+    def bottom_track(self) -> FeatureTrack:
+        """Bottom track"""
+        feature_tracks = [t for t in self.get_tracks() if isinstance(t, FeatureTrack)]
+        if len(feature_tracks) == 0:
+            err_msg = "No track found. Can't access 'bottom_track' property."
+            raise ValueError(err_msg)
+        return feature_tracks[-1]
+
     @property
     def max_track_size(self) -> int:
         """Max track size"""
@@ -371,10 +391,11 @@ class GenomeViz:
         if len(self.get_tracks()) == 0:
             raise ValueError("No tracks are defined for plotting figure.")
         self._tracks = [t for t in self.get_tracks() if not isinstance(t, TickTrack)]
+        max_track_size = self.max_track_size
         if self.tick_style is not None:
             self._tracks.append(
                 TickTrack(
-                    self.max_track_size,
+                    max_track_size,
                     self.tick_labelsize,
                     self.track_spines,
                     self.tick_track_ratio,
@@ -397,7 +418,7 @@ class GenomeViz:
         )
         for idx, track in enumerate(self.get_tracks(subtrack=True)):
             # Create new track subplot
-            xlim, ylim = (0, self.max_track_size), track.ylim
+            xlim, ylim = (0, max_track_size), track.ylim
             ax: Axes = figure.add_subplot(
                 spec[idx], xlim=xlim, ylim=ylim, fc="none", zorder=track.zorder
             )
@@ -411,22 +432,19 @@ class GenomeViz:
             if isinstance(track, FeatureTrack):
                 # Plot track label
                 if track.labelsize != 0:
-                    margin = -self.max_track_size * track.labelmargin
+                    margin = -max_track_size * track.labelmargin
                     ax.text(margin, 0, **track.label_params)
                 # Plot track scale line
                 xmin, xmax = track_offset, track.size + track_offset
-                ax.hlines(0, xmin, xmax, "black", linewidth=track.linewidth)
+                ax.hlines(0, xmin, xmax, track.linecolor, linewidth=track.linewidth)
 
                 for feature in [f + track_offset for f in track.features]:
-                    # Don't draw too small feature (To reduce drawing time)
-                    if feature.length < self.max_track_size * self.plot_size_thr:
+                    # Don't plot too small feature (To reduce drawing time)
+                    if feature.length < max_track_size * self.plot_size_thr:
                         continue
-                    # Plot feature object
-                    obj_params = feature.obj_params(self.max_track_size, ylim)
-                    ax.arrow(**obj_params)
-                    # Plot feature text
-                    if feature.labelsize != 0:
-                        ax.text(**feature.text_params(ylim))
+                    # Plot feature patch & label text
+                    feature.plot_feature(ax, max_track_size, ylim)
+                    feature.plot_label(ax, ylim)
 
             elif isinstance(track, FeatureSubTrack):
                 # No specific plans to implementation at this time
@@ -435,8 +453,7 @@ class GenomeViz:
             elif isinstance(track, LinkTrack):
                 for link in track.links:
                     link = link.add_offset(self._track_name2offset)
-                    p = patches.PathPatch(link.path(ylim), fc=link.color, linewidth=0)
-                    ax.add_patch(p)
+                    link.plot_link(ax, ylim)
 
             elif isinstance(track, TickTrack):
                 if self.tick_style == "axis":
