@@ -2,9 +2,11 @@ from __future__ import annotations
 
 from copy import deepcopy
 from dataclasses import dataclass
-from typing import Dict, Optional, Tuple
+from typing import Any, Dict, Optional, Tuple
 
 from matplotlib import colors
+from matplotlib.figure import Axes
+from matplotlib.patches import PathPatch
 from matplotlib.path import Path
 
 
@@ -26,8 +28,10 @@ class Link:
     vmax: float = 100
     curve: bool = False
     size_ratio: float = 0.9
+    patch_kws: Optional[Dict[str, Any]] = None
 
     def __post_init__(self):
+        # Check color string
         if not colors.is_color_like(self.normal_color):
             err_msg = f"'normal_color={self.normal_color}' is not color like."
             raise ValueError(err_msg)
@@ -39,60 +43,65 @@ class Link:
             err_msg = "'size_ratio' must be '0 <= value <= 1' "
             err_msg += f"(value={self.size_ratio})"
             raise ValueError(err_msg)
+        # Check range of interpolation value
         if self.v is not None:
-            if not self.vmin <= self.v <= self.vmax:
+            if not 0 <= self.vmin <= self.v <= self.vmax <= 100:
                 err_msg = "'Interpolation value must be "
-                err_msg += f"'{self.vmin} <= value <= {self.vmax}' (value={self.v})"
+                err_msg += "'0 <= vmin <= value <= vmax <= 100' "
+                err_msg += f" (value={self.v}, vmin={self.vmin}, vmax={self.vmax})"
                 raise ValueError(err_msg)
 
-    def path(self, ylim: Tuple[float, float] = (-1.0, 1.0)) -> Path:
-        """Link path
+    def plot_link(self, ax: Axes, ylim: Tuple[float, float] = (-1.0, 1.0)) -> None:
+        """Plot link
 
         Parameters
         ----------
+        ax : Axes
+            Matplotlib axes object to be plotted
         ylim: Tuple[flaot, float], optional
             Min-Max y coordinatess
+        """
+        ymin, ymax = ylim[0] * self.size_ratio, ylim[1] * self.size_ratio
+        start1, end1 = self.track_start1 - 1, self.track_end1
+        start2, end2 = self.track_start2 - 1, self.track_end2
+        if self.curve:
+            ctl_y_point1, ctl_y_point2 = ymax / 3, ymin / 3
+            path_data = [
+                (Path.MOVETO, (start2, ymin)),
+                (Path.LINETO, (end2, ymin)),
+                (Path.CURVE4, (end2, ctl_y_point2)),
+                (Path.CURVE4, (end1, ctl_y_point1)),
+                (Path.LINETO, (end1, ymax)),
+                (Path.LINETO, (start1, ymax)),
+                (Path.CURVE4, (start1, ctl_y_point1)),
+                (Path.CURVE4, (start2, ctl_y_point2)),
+                (Path.LINETO, (start2, ymin)),
+            ]
+        else:
+            path_data = [
+                (Path.MOVETO, (start2, ymin)),
+                (Path.LINETO, (end2, ymin)),
+                (Path.LINETO, (end1, ymax)),
+                (Path.LINETO, (start1, ymax)),
+                (Path.LINETO, (start2, ymin)),
+            ]
+        codes, verts = zip(*path_data)
+        ax.add_patch(PathPatch(Path(verts, codes), **self._patch_kwargs()))
+
+    def _patch_kwargs(self) -> Dict[str, Any]:
+        """Patch keyword arguments dict
 
         Returns
         -------
-        path : Path
-            Link path
+        patch_kwargs : Dict[str, Any]
+            Patch keyword arguments dict
         """
-        ymin, ymax = ylim[0] * self.size_ratio, ylim[1] * self.size_ratio
-        if self.curve:
-            codes = [
-                Path.MOVETO,
-                Path.LINETO,
-                Path.CURVE4,
-                Path.CURVE4,
-                Path.LINETO,
-                Path.LINETO,
-                Path.CURVE4,
-                Path.CURVE4,
-                Path.LINETO,
-            ]
-            ctl_y_point1, ctl_y_point2 = ymax / 3, ymin / 3
-            verts = (
-                (self.track_start2, ymin),
-                (self.track_end2, ymin),
-                (self.track_end2, ctl_y_point2),
-                (self.track_end1, ctl_y_point1),
-                (self.track_end1, ymax),
-                (self.track_start1, ymax),
-                (self.track_start1, ctl_y_point1),
-                (self.track_start2, ctl_y_point2),
-                (self.track_start2, ymin),
-            )
-        else:
-            codes = [Path.MOVETO, Path.LINETO, Path.LINETO, Path.LINETO, Path.LINETO]
-            verts = (
-                (self.track_start2, ymin),
-                (self.track_end2, ymin),
-                (self.track_end1, ymax),
-                (self.track_start1, ymax),
-                (self.track_start2, ymin),
-            )
-        return Path(verts, codes)
+        patch_kws = {} if self.patch_kws is None else self.patch_kws
+        return {
+            "fc": self.color,
+            "lw": 0,
+            **patch_kws,
+        }
 
     @property
     def color(self) -> str:
