@@ -1,11 +1,11 @@
 from __future__ import annotations
 
 import math
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, Callable, Dict, List, Optional, Tuple
 
 from matplotlib.figure import Axes
 
-from pygenomeviz.feature import Feature
+from pygenomeviz.feature import ExonFeature, Feature
 from pygenomeviz.genbank import Genbank
 from pygenomeviz.link import Link
 
@@ -18,8 +18,6 @@ class Track:
         name: str,
         size: int,
         labelsize: int = 0,
-        labelmargin: float = 0,
-        linewidth: int = 0,
         spines: bool = False,
         ratio: float = 1.0,
     ):
@@ -32,10 +30,6 @@ class Track:
             Track size
         labelsize : int, optional
             Track label size
-        labelmargin : float, optional
-            Track label margin
-        linewidth : int, optional
-            Track line width
         spines : bool, optional
             Display track spines
         ratio : float, optional
@@ -44,8 +38,6 @@ class Track:
         self.name = name
         self.size = size
         self.labelsize = labelsize
-        self.labelmargin = labelmargin
-        self.linewidth = linewidth
         self.spines = spines
         self.ratio = ratio
         self._offset: Optional[int] = None
@@ -118,6 +110,7 @@ class FeatureTrack(Track):
         labelsize: int = 20,
         labelmargin: float = 0.01,
         linewidth: int = 1,
+        linecolor: str = "black",
         spines: bool = False,
         ratio: float = 1.0,
     ):
@@ -134,12 +127,17 @@ class FeatureTrack(Track):
             Track label margin
         linewidth : int, optional
             Track line width
+        linecolor : str, optional
+            Track line color
         spines : bool, optional
             Display track spines
         ratio : float, optional
             Track height ratio
         """
-        super().__init__(name, size, labelsize, labelmargin, linewidth, spines, ratio)
+        super().__init__(name, size, labelsize, spines, ratio)
+        self.labelmargin = labelmargin
+        self.linewidth = linewidth
+        self.linecolor = linecolor
         self.features: List[Feature] = []
         self.subtracks: List[FeatureSubTrack] = []
 
@@ -162,7 +160,7 @@ class FeatureTrack(Track):
         self,
         start: int,
         end: int,
-        strand: int,
+        strand: int = 1,
         label: str = "",
         labelsize: int = 15,
         labelcolor: str = "black",
@@ -175,7 +173,8 @@ class FeatureTrack(Track):
         labelhpos: str = "center",
         labelha: str = "left",
         arrow_shaft_ratio: float = 0.5,
-        size_ratio: float = 0.9,
+        size_ratio: float = 1.0,
+        patch_kws: Optional[Dict[str, Any]] = None,
     ) -> None:
         """Add feature to track
 
@@ -185,7 +184,7 @@ class FeatureTrack(Track):
             Featrue start position
         end : int
             Feature end position
-        strand : int
+        strand : int, optional
             Feature strand
         label : str, optional
             Feature label
@@ -194,7 +193,7 @@ class FeatureTrack(Track):
         labelcolor : str, optional
             Feature label color
         plotstyle : str, optional
-            Feature plot style (`bigarrow`|`arrow`|`bigbox`|`box`)
+            Feature plot style (`bigarrow`|`arrow`|`bigbox`|`box`|`bigrbox`|`rbox`)
         facecolor : str, optional
             Feature facecolor
         edgecolor : str, optional
@@ -214,7 +213,17 @@ class FeatureTrack(Track):
             Feature arrow shaft ratio
         size_ratio : float, optional
             Feature size ratio to track
+        patch_kws : Optional[Dict[str, Any]], optional
+            Optional keyword arguments to pass to feature Patch object.
+            See https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html
+            for detailed parameters.
         """
+        # Check if start & end positions are within appropriate track range
+        if not 0 <= start <= end <= self.size:
+            err_msg = f"start-end must be '0 <= start <= end <= {self.size}' "
+            err_msg += f"(start={start}, end={end})"
+            raise ValueError(err_msg)
+
         self.features.append(
             Feature(
                 start,
@@ -233,6 +242,109 @@ class FeatureTrack(Track):
                 labelha,
                 arrow_shaft_ratio,
                 size_ratio,
+                patch_kws,
+            )
+        )
+
+    def add_exon_feature(
+        self,
+        exon_regions: List[Tuple[int, int]],
+        strand: int = 1,
+        label: str = "",
+        labelsize: int = 15,
+        labelcolor: str = "black",
+        plotstyle: str = "bigarrow",
+        facecolor: str = "orange",
+        edgecolor: str = "black",
+        linewidth: float = 0,
+        labelrotation: int = 45,
+        labelvpos: str = "strand",
+        labelhpos: str = "center",
+        labelha: str = "left",
+        arrow_shaft_ratio: float = 0.5,
+        size_ratio: float = 1.0,
+        exon_labels: Optional[List[str]] = None,
+        exon_label_kws: Optional[Dict[str, Any]] = None,
+        patch_kws: Optional[Dict[str, Any]] = None,
+        intron_patch_kws: Optional[Dict[str, Any]] = None,
+    ) -> None:
+        """Add exon feature to track
+
+        Parameters
+        ----------
+        exon_regions : List[Tuple[int, int]]
+            Exon feature start-end postion list
+        strand : int, optional
+            Feature strand
+        label : str, optional
+            Feature label
+        labelsize : int, optional
+            Feature label size
+        labelcolor : str, optional
+            Feature label color
+        plotstyle : str, optional
+            Feature plot style (`bigarrow`|`arrow`|`bigbox`|`box`|`bigrbox`|`rbox`)
+        facecolor : str, optional
+            Feature facecolor
+        edgecolor : str, optional
+            Feature edgecolor
+        linewidth : float, optional
+            Feature edge linewidth
+        labelrotation : int, optional
+            Feature label rotation
+        labelvpos : str, optional
+            Feature label vertical position (`top`|`center`|`bottom`|`strand`)
+            If 'strand' is set, 'top' or 'bottom' is auto selected by strand.
+        labelhpos : str, optional
+            Feature label horizontal position (`left`|`center`|`right`)
+        labelha : str, optional
+            Feature label horizontal alignment (`left`|`center`|`right`)
+        arrow_shaft_ratio : float, optional
+            Feature arrow shaft ratio
+        size_ratio : float, optional
+            Feature size ratio to track
+        exon_labels: Optional[List[str]], optional
+            Exon labels. Array length must be same as `exon_regions`.
+        exon_label_kws : Optional[Dict[str, Any]], optional
+            Optional keyword arguments to pass to Axes.text method for exon label.
+            Use this option when plotting both Feature & Exon labels.
+            See https://matplotlib.org/stable/api/_as_gen/matplotlib.axes.Axes.text.html
+            for detailed parameters.
+        patch_kws : Optional[Dict[str, Any]], optional
+            Optional keyword arguments to pass to exon feature Patch object.
+            See https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html
+            for detailed parameters.
+        intron_patch_kws : Optional[Dict[str, Any]], optional
+            Optional keyword arguments to pass to intron feature Patch object.
+        """
+        # Check if start & end positions are within appropriate track range
+        for (exon_start, exon_end) in exon_regions:
+            if not 0 <= exon_start <= exon_end <= self.size:
+                err_msg = f"Exon start-end must be '0 <= start <= end <= {self.size}' "
+                err_msg += f"(exon_regions={exon_regions})"
+                raise ValueError(err_msg)
+
+        self.features.append(
+            ExonFeature(
+                exon_regions,
+                strand,
+                label,
+                labelsize,
+                labelcolor,
+                plotstyle,
+                facecolor,
+                edgecolor,
+                linewidth,
+                labelrotation,
+                labelvpos,
+                labelhpos,
+                labelha,
+                arrow_shaft_ratio,
+                size_ratio,
+                exon_labels,
+                exon_label_kws,
+                patch_kws,
+                intron_patch_kws,
             )
         )
 
@@ -241,7 +353,7 @@ class FeatureTrack(Track):
         gbk: Genbank,
         feature_type: str = "CDS",
         label_type: Optional[str] = None,
-        label_filter: Optional[List[str]] = None,
+        label_handle_func: Optional[Callable[[str], str]] = None,
         allow_partial: bool = True,
         labelsize: int = 15,
         labelcolor: str = "black",
@@ -254,7 +366,8 @@ class FeatureTrack(Track):
         labelhpos: str = "center",
         labelha: str = "left",
         arrow_shaft_ratio: float = 0.5,
-        size_ratio: float = 0.9,
+        size_ratio: float = 1.0,
+        patch_kws: Optional[Dict[str, Any]] = None,
     ):
         """Add features from genbank record
 
@@ -266,9 +379,10 @@ class FeatureTrack(Track):
             Feature type (e.g. `CDS`,`rRNA`,`tRNA`,etc...)
         label_type : Optional[str], optional
             Label type (e.g. `gene`,`protein_id`,`product`,etc...)
-        label_filter : Optional[List[str]], optional
-            Label filter string list (e.g. `hypothetical`, `uncharacterized`)
-            If label contains target string, make it empty.
+        label_handle_func : Optional[Callable[[str], str]], optional
+            Labels are handled by user defined function.
+            Useful for filtering out unnecesary labels such as `hypothetical ~~~`,
+            omitting labels with long characters, etc.
         allow_partial : bool, optional
             If True, features that are partially included in range are also extracted
         labelsize : int, optional
@@ -276,7 +390,7 @@ class FeatureTrack(Track):
         labelcolor : str, optional
             Feature label color
         plotstyle : str, optional
-            Feature plot style (`bigarrow`|`arrow`|`bigbox`|`box`)
+            Feature plot style (`bigarrow`|`arrow`|`bigbox`|`box`|`bigrbox`|`rbox`)
         facecolor : str, optional
             Feature facecolor
         edgecolor : str, optional
@@ -295,6 +409,10 @@ class FeatureTrack(Track):
             Feature arrow shaft ratio
         size_ratio : float, optional
             Feature size ratio to track
+        patch_kws : Optional[Dict[str, Any]], optional
+            Optional keyword arguments to pass to feature Patch object.
+            See https://matplotlib.org/stable/api/_as_gen/matplotlib.patches.Patch.html
+            for detailed parameters.
         """
         target_features = gbk.extract_features(feature_type, None, True, allow_partial)
         for feature in target_features:
@@ -305,9 +423,9 @@ class FeatureTrack(Track):
                 label = ""
             else:
                 label = feature.qualifiers.get(label_type, [""])[0]
-                if label_filter is not None:
-                    for filter_str in label_filter:
-                        label = "" if filter_str in label else label
+                if label_handle_func is not None:
+                    label = label_handle_func(label)
+
             self.features.append(
                 Feature(
                     start,
@@ -326,6 +444,7 @@ class FeatureTrack(Track):
                     labelha,
                     arrow_shaft_ratio,
                     size_ratio,
+                    patch_kws,
                 )
             )
 
@@ -334,7 +453,19 @@ class FeatureSubTrack(Track):
     """FeatureSubTrack Class"""
 
     def __init__(self, name: str, size: int, spines: bool = False, ratio: float = 1.0):
-        super().__init__(name, size, 0, 0, 0, spines, ratio)
+        """
+        Parameters
+        ----------
+        name : str
+            Sub track name
+        size : int
+            Sub track size
+        spines : bool, optional
+            Display track spines
+        ratio : float, optional
+            Sub track height ratio
+        """
+        super().__init__(name, size, 0, spines, ratio)
 
 
 class LinkTrack(Track):
@@ -351,7 +482,7 @@ class LinkTrack(Track):
         ratio : float, optional
             Track height ratio
         """
-        super().__init__(name, 0, 0, 0, 0, spines, ratio)
+        super().__init__(name, 0, 0, spines, ratio)
         self.links: List[Link] = []
 
     def add_link(self, link: Link) -> None:
@@ -390,7 +521,7 @@ class TickTrack(Track):
         tick_style : str, optional
             Tick style (`axis`|`bar`)
         """
-        super().__init__("tick", size, labelsize, 0, 0, spines, ratio)
+        super().__init__("tick", size, labelsize, spines, ratio)
         self.tick_style = tick_style
 
     @property
